import requests
from requests.auth import HTTPBasicAuth

from .customers import Customers
from .events import Events

BASE_URL = 'https://www.aboardly.com/api/v1'

class Aboardly(object):

    def __init__(self, username, password, base_url=BASE_URL):
        auth = HTTPBasicAuth(username, password)
        self.customers = Customers(auth, base_url)
        self.events = Events(auth, base_url)



import requests

class Customers(object):

    def __init__(self, auth, base_url):
        self.auth = auth
        self.base_url = base_url

    def upsert(self, customer_id, data={}):
        url = self.base_url + "/customers/" + customer_id
        return requests.put(url, data=data, auth=self.auth)



import requests

class Events(object):

    def __init__(self, auth, base_url):
        self.auth = auth
        self.base_url = base_url

    def create(self, customer_id, event_name):
        url = self.base_url + "/customers/" + customer_id + "/events/" + event_name
        return requests.post(url, auth=self.auth)
